@@ -1,6 +1,6 @@
 from typing import Any
 
-from dagster import InputDefinition, Nothing, OutputDefinition
+from dagster import In, Nothing, Out
 from qdk.base import BaseComponent
 
 
@@ -9,12 +9,8 @@ class BaseLoader(BaseComponent):
     tags = {
         "kind": "loader",
     }
-    input_defs = [
-        InputDefinition("after", Nothing),
-    ]
-    output_defs = [
-        OutputDefinition(Any, "out"),
-    ]
+    input_defs = {"after": In(Nothing)}
+    output_defs = {"out": Out(Any)}
 
     @classmethod
     def load(cls) -> Any:
