@@ -2,16 +2,16 @@ from typing import Any, Dict, List, Optional, Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import Field, Noneable, OutputDefinition, Permissive
+from dagster import Field, Noneable, Out, Permissive
 from qdk.dagster_types import DataFrameType
 from qdk.loader.base import BaseLoader
 from qdk.s3_connection import S3Connection
 
 
 class DataFrameLoader(BaseLoader):
-    output_defs = [
-        OutputDefinition(DataFrameType, "df"),
-    ]
+    output_defs = {
+        "out": Out(DataFrameType),
+    }
 
     config_schema = {
         "uri": Field(
