@@ -2,9 +2,9 @@ from typing import Optional, Tuple, Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import InputDefinition, Nothing
+from dagster import In, Nothing
 from dagster import Optional as DagsterOptional
-from dagster import OutputDefinition
+from dagster import Out
 from qdk.base import BaseComponent
 from qdk.dagster_types import DataFrameType, ModelType, SeriesType
 
@@ -16,31 +16,15 @@ class BaseTrainer(BaseComponent):
     tags = {
         "kind": "training",
     }
-    input_defs = [
-        InputDefinition(
-            "X",
-            DataFrameType,
-        ),
-        InputDefinition(
-            "y",
-            DagsterOptional[SeriesType],
-        ),
-        InputDefinition(
-            "model",
-            DagsterOptional[ModelType],
-        ),
-    ]
-    output_defs = [
-        OutputDefinition(
-            ModelType,
-            "model",
-        ),
-        OutputDefinition(
-            DataFrameType,
-            "data",
-            is_required=False,
-        ),
-    ]
+    input_defs = {
+        "X": In(DataFrameType),
+        "y": In(DataFrameType),
+        "model": In(DagsterOptional[SeriesType]),
+    }
+    output_defs = {
+        "model": Out(ModelType),
+        "data": Out(DataFrameType, is_required=False),
+    }
 
     @classmethod
     def train(
