@@ -2,7 +2,7 @@ from typing import Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import InputDefinition
+from dagster import In
 from qdk.dagster_types import DataFrameType, SeriesType
 from qdk.training.base import BaseTrainer
 
@@ -10,11 +10,12 @@ from sklearn.base import BaseEstimator
 
 
 class SklearnTrainer(BaseTrainer):
-    input_defs = [
-        InputDefinition("X", DataFrameType),
-        InputDefinition("y", SeriesType),
-        InputDefinition("model", BaseEstimator),
-    ]
+    input_defs = {
+        "X": In(DataFrameType),
+        "y": In(SeriesType),
+        "model": In(BaseEstimator),
+    }
+
     required_resource_keys = {"mlflow"}
 
     @classmethod
