@@ -2,7 +2,7 @@ from typing import Dict, List, Tuple, Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import Field, InputDefinition, OutputDefinition
+from dagster import Field, In, Out
 from dask_ml.model_selection import train_test_split
 from qdk.dagster_types import DataFrameType, SeriesType
 from qdk.transform.base import BaseTransformer
@@ -11,13 +11,13 @@ import yake
 
 
 class TrainTestTransformer(BaseTransformer):
-    input_defs = [InputDefinition("df", DataFrameType)]
-    output_defs = [
-        OutputDefinition(DataFrameType, "X_train"),
-        OutputDefinition(DataFrameType, "X_test"),
-        OutputDefinition(SeriesType, "y_train"),
-        OutputDefinition(SeriesType, "y_test"),
-    ]
+    input_defs = {"df": In(DataFrameType)}
+    output_defs = {
+        "X_train": Out(DataFrameType),
+        "X_test": Out(DataFrameType),
+        "y_train": Out(SeriesType),
+        "y_test": Out(SeriesType),
+    }
     config_schema = {
         "target_column": Field(
             str,
